@@ -11,7 +11,7 @@ import (
 	"github.com/99designs/aws-vault/v7/iso8601"
 	"github.com/99designs/aws-vault/v7/vault"
 	"github.com/99designs/keyring"
-	"github.com/alecthomas/kingpin"
+	"github.com/alecthomas/kingpin/v2"
 	"github.com/aws/aws-sdk-go-v2/aws"
 	ini "gopkg.in/ini.v1"
 )
@@ -52,7 +52,7 @@ func ConfigureExportCommand(app *kingpin.Application, a *AwsVault) {
 		Short('t').
 		StringVar(&input.Config.MfaToken)
 
-	cmd.Flag("format", fmt.Sprintf("Format to output credentials. Valid values are %s, %s and %s", FormatTypeEnv, FormatTypeExportEnv, FormatTypeExportJSON)).
+	cmd.Flag("format", fmt.Sprintf("Format to output credentials. Valid formats: %s, %s, %s, %s", FormatTypeEnv, FormatTypeExportEnv, FormatTypeExportJSON, FormatTypeExportINI)).
 		Default(FormatTypeEnv).
 		EnumVar(&input.Format, FormatTypeEnv, FormatTypeExportEnv, FormatTypeExportJSON, FormatTypeExportINI)
 
@@ -96,7 +96,7 @@ func ExportCommand(input ExportCommandInput, f *vault.ConfigFile, keyring keyrin
 	}
 
 	ckr := &vault.CredentialKeyring{Keyring: keyring}
-	credsProvider, err := vault.NewTempCredentialsProvider(config, ckr, input.NoSession, true)
+	credsProvider, err := vault.NewTempCredentialsProvider(config, ckr, input.NoSession, false)
 	if err != nil {
 		return fmt.Errorf("Error getting temporary credentials: %w", err)
 	}
